@@ -118,9 +118,22 @@ static char	*uuname;
 static int 	Encoded = 0;
 static off_t	Encodeflag_offset;	/* offset in file where encoded flag is stored */
 
-static	void admin(), cmt_ba(), putmrs(), code();
-static	char *adjust(), *getval();
-static	int val_list(), pos_ser(), range(), fgetchk();
+	int	main __PR((int argc, char **argv));
+static	void	admin __PR((char *afile));
+static	int	fgetchk __PR((FILE *inptr, char *file, struct packet *pkt, int fflag));
+	void	clean_up __PR((void));
+static	void	cmt_ba __PR((register struct deltab *dt, char *str));
+static	void	putmrs __PR((struct packet *pkt));
+static	char *	adjust __PR((char *line));
+static	char *	getval __PR((register char *sourcep, register char *destp));
+static	int	val_list __PR((register char *list));
+static	int	pos_ser __PR((char *s1, char *s2));
+static	int	range __PR((register char *line));
+static	void	code __PR((FILE *iptr, char *afile, int offset, int thash, struct packet *gpkt));
+
+/*static	void admin(), cmt_ba(), putmrs(), code();*/
+/*static	char *adjust(), *getval();*/
+/*static	int val_list(), pos_ser(), range(), fgetchk();*/
 
 extern int	org_ihash;
 extern int	org_chash;
@@ -150,12 +163,10 @@ char *argv[];
 	/* 
 	 * Set directory to search for general l10n SCCS messages.
 	 */
-#ifdef	USE_NLS
 	bindtextdomain(NOGETTEXT("SUNW_SPRO_SCCS"),
 	   NOGETTEXT("/usr/ccs/lib/locale/"));
 	
 	textdomain(NOGETTEXT("SUNW_SPRO_SCCS"));
-#endif
 
 	/*
 	Set flags for 'fatal' to issue message, call clean-up
@@ -289,7 +300,7 @@ char *argv[];
 					}
 					break;
 				case LOCKFLAG:
-					if (*p == NULL) {
+					if (*p == '\0') {
 						fatal(gettext("bad list format (ad27)"));
 					}
 					if (*p) {
@@ -525,7 +536,7 @@ char	*afile;
 	struct deltab dt;	/* see file defines.h */
 	struct stats stats;	/* see file defines.h */
 	struct stat sbuf;
-	FILE	*iptr;
+	FILE	*iptr = NULL;
 	register int k;
 	register char *cp;
 	register signed char *q;
@@ -1032,11 +1043,17 @@ char	*afile;
 				from_stdin = 1;
 				ifile 	   = stdin_file_buf;
 				strcpy(stdin_file_buf, "/tmp/admin.XXXXXX");
-				mktemp(stdin_file_buf);
 				cur_umask = umask((mode_t)((S_IRWXU|S_IRWXG|S_IRWXO)&~(S_IRUSR|S_IWUSR)));
+#ifdef	HAVE_MKSTEMP
+				if ((out = fdopen(mkstemp(ifile), "w")) == NULL) {
+					xmsg(ifile, NOGETTEXT("admin"));
+				}
+#else
+				mktemp(stdin_file_buf);
 				if ((out = fopen(ifile, "w")) == NULL) {
 					xmsg(ifile, NOGETTEXT("admin"));
 				}
+#endif
 				(void)umask(cur_umask);
 				/*CONSTCOND*/
 				while (1) {
