@@ -78,12 +78,21 @@ static char	cmr[CMRLIMIT];
 static int	cmri = 0;
 /* End of insertion */
 
-void	fredck(), escdodelt(), enter();
-static int	cmrinsert();
-static void	idsetup(), makgdate(), prfx(), wrtpfile(), gen_lfile();
-static char	*idsubst(), *_trans();
+	void    clean_up __PR((void));
+	void	escdodelt __PR((struct packet *pkt));
+	void	fredck	__PR((struct packet *pkt));
+	void	enter	__PR((struct packet *pkt, int ch, int n, struct sid *sidp));
 
-static	void	get();
+	int	main __PR((int argc, char **argv));
+static void	get __PR((char *file));
+static void	gen_lfile __PR((struct packet *pkt));
+static void	idsetup __PR((struct packet *pkt));
+static void	makgdate __PR((char *old, char *new));
+static char *	idsubst __PR((struct packet *pkt, char *line));
+static char *	_trans __PR((char *tp, char *str, char *rest));
+static void	prfx __PR((struct packet *pkt));
+static void	wrtpfile __PR((struct packet *pkt, char *inc, char *exc));
+static int	cmrinsert __PR((void));
 
 int
 main(argc,argv)
@@ -104,11 +113,9 @@ register char *argv[];
 	/* 
 	 * Set directory to search for general l10n SCCS messages.
 	 */
-#ifdef	USE_NLS
 	bindtextdomain(NOGETTEXT("SUNW_SPRO_SCCS"),
 	   NOGETTEXT("/usr/ccs/lib/locale/"));
 	textdomain(NOGETTEXT("SUNW_SPRO_SCCS"));
-#endif
 
 	Fflags = FTLEXIT | FTLMSG | FTLCLN;
 	current_optind = 1;
