@@ -100,13 +100,29 @@ static struct	tm	*Dtime;
 static struct tm 	Date_time;
 static struct tm 	Del_Date_time;
 
-static void	dodeltbl(), deltblchk(), printfile(), getit(), aux_create();
-static void	idsetup(), putcom(), ck_spec(), printflags();
-static void	read_to(), putmr(), getbody(), scanspec(), process();
-static int 	getadel(), sidcmp(), getstats(), invalid(), read_mod();
-static FILE	*maket();
+	void    clean_up __PR((void));
 
-void	clean_up();
+	int	main __PR((int argc, char **argv));
+static void	process __PR((char *file));
+static void	dodeltbl __PR((struct packet *pkt));
+static void	scanspec __PR((char *spec, struct deltab *dtp, struct stats *statp));
+static int	invalid __PR((char *i_sid));
+static void	deltblchk __PR((struct packet *pkt));
+static int	getstats __PR((struct packet *pkt, struct stats *statp));
+static int	sidcmp __PR((struct sid *sid1, struct sid *sid2));
+static int	getadel __PR((struct packet *pkt, struct deltab *dt));
+static FILE *	maket __PR((char *file));
+static void	printfile __PR((char *file));
+static int	read_mod __PR((struct packet *pkt));
+static void	getbody __PR((struct sid *gsid, struct packet *pkt));
+static void	getit __PR((char *str, char *cp));
+static void	aux_create __PR((FILE *iop, char *file, int delchar));
+static void	idsetup __PR((struct sid *gsid, struct packet *pkt, time_t *bdate));
+static void	putmr __PR((char *cp));
+static void	putcom __PR((char *cp));
+static void	read_to __PR((int ch, struct packet *pkt));
+static void	printflags __PR((void));
+static void	ck_spec __PR((char *p));
 
 int
 main(argc,argv)
@@ -116,7 +132,7 @@ char *argv[];
 	register int j;
 	register char *p;
 	int  c;
-	int strlength;
+	int strlength = 0;
 	extern int Fcnt;
 	int current_optind;
 	int no_arg;
@@ -128,12 +144,10 @@ char *argv[];
 	/* 
 	 * Set directory to search for general l10n SCCS messages.
 	 */
-#ifdef	USE_NLS
 	bindtextdomain(NOGETTEXT("SUNW_SPRO_SCCS"),
 	   NOGETTEXT("/usr/ccs/lib/locale/"));
 
 	textdomain(NOGETTEXT("SUNW_SPRO_SCCS"));
-#endif
 
 	/*
 	Set flags for 'fatal' to issue message, call clean-up
@@ -1102,9 +1116,17 @@ maket(file)
 char	*file;
 {
 	FILE *iop;
+	mode_t cur_umask;
 
 	copy(tempskel,file);	/* copy file name into the skeleton */
-	iop = xfcreat(mktemp(file),0644);
+				/* umask 0133 -> create mode 0644 */
+	cur_umask = umask((mode_t)((S_IRWXU|S_IRWXG|S_IRWXO)&~(S_IRUSR|S_IWUSR|S_IRGRP|S_IROTH)));
+#ifdef	HAVE_MKSTEMP
+	iop = fdfopen(mkstemp(file), 1);
+#else
+	iop = xfcreat(mktemp(file), 0644);
+#endif
+	(void)umask(cur_umask);
 
 	return(iop);
 }
@@ -1163,7 +1185,7 @@ register struct packet *pkt;
 			if (iod == END)
 				remq(pkt,ser);
 			else
-				addq(pkt,ser,iod == INS ? NO : NULL,iod, USER);
+				addq(pkt,ser,iod == INS ? NO : 0, iod, USER);
 		}
 	}
 	if (HAD_BD) {
