@@ -89,12 +89,20 @@ static int D_serial;
 static struct utsname un;
 static char *uuname;
 
-void	clean_up(), escdodelt();
-
-static void	rdpfile(), put_delmrs(), ckmrs();
-static void	putmrs(), split_mrs();
-static int	verif(), esccmfdelt(), testfred(), msg();
-static	void	rmchg();
+	int	main __PR((int argc, char **argv));
+static void	rmchg __PR((char *file));
+	void	escdodelt __PR((struct packet *pkt));
+static int	esccmfdelt __PR((struct packet *pkt));
+	void	fredck	__PR((struct packet *pkt));
+static int	verif __PR((char **test, struct packet *pkt));
+static int	msg __PR((char *app, char *name, char *cmrs, char *stats, char *sids, char *fred));
+static int	testfred __PR((char *cmr, char *fredfile));
+static void	split_mrs __PR((void));
+static void	putmrs __PR((struct packet *pkt));
+	void    clean_up __PR((void));
+static void	rdpfile __PR((struct packet *pkt, struct sid *sp));
+static void	ckmrs __PR((struct packet *pkt, char *p));
+static void	put_delmrs __PR((struct packet *pkt));
 
 
 int
@@ -115,12 +123,10 @@ char *argv[];
 	/* 
 	 * Set directory to search for general l10n SCCS messages.
 	 */
-#ifdef	USE_NLS
 	bindtextdomain(NOGETTEXT("SUNW_SPRO_SCCS"),
 	   NOGETTEXT("/usr/ccs/lib/locale/"));
 	
 	textdomain(NOGETTEXT("SUNW_SPRO_SCCS"));
-#endif
 
 	/*
 	Set flags for 'fatal' to issue message, call clean-up
@@ -618,8 +624,8 @@ struct packet *pkt;
 		 p += 3;
 		 strcpy(holder,p);
 		 i=0;
-		 outhold[0]=NULL;
-		 holdptr[0]=strtok(holder,",\n");
+		 outhold[0]= '\0';
+		 holdptr[0]= strtok(holder,",\n");
 		 while(holdptr[++i] = strtok(0,",\n"));
 		 if(!holdptr[1])
 			{
@@ -634,7 +640,7 @@ struct packet *pkt;
 			{
 			 printf(gettext("do you want to delete %s\n"),
 				holdptr[j]);
-			 gets(answ);
+			 fgets(answ, sizeof (answ), stdin);
 			 if(imatch(NOGETTEXT("y"),answ))
 				{
 				 if(numcmrs <= 1)
@@ -671,8 +677,8 @@ struct packet *pkt;
 			putline(pkt,0);
 			/* place new line */
 			pp=strend(outhold);
-			*pp=NULL;
-			*--pp=NULL;
+			*pp= '\0';
+			*--pp= '\0';
 			sprintf(str,"%c%c %s\n",CTLCHAR,MRNUM,outhold);
 			putline(pkt,str);
 			return(0);
@@ -798,8 +804,11 @@ testfred(cmr,fredfile)
 		cmrh[0]=cmr;
 		dcmrh[0]=dcmr;
 		return(sweep(SEQVERIFY,fredfile,NULL,'\n',WHITE,80,cmrh,NULL,NULL,
-		(int(*)())NULL,(int(*)())NULL) == FOUND || sweep(SEQVERIFY,fredfile
-		,NULL,'\n',WHITE,80,dcmrh,NULL,NULL,(int(*)())NULL,(int(*)())NULL)
+		(int(*)__PR((char *, int, char **)))NULL,
+		(int(*)__PR((char **, char **, int)))NULL) == FOUND || sweep(SEQVERIFY,fredfile
+		,NULL,'\n',WHITE,80,dcmrh,NULL,NULL,
+		(int(*)__PR((char *, int, char **)))NULL,
+		(int(*)__PR((char **, char **, int)))NULL)
 		== FOUND);
 	}
 	
