@@ -70,7 +70,6 @@ static char	name[50];	/* storage for name (-m) value */
 static char	*Argv[BUFSIZ];
 static char	line[BUFSIZ];
 static char	save_line[BUFSIZ];
-static char	*get_line();	/* function returning ptr to line read */
 
 static struct delent {		/* structure for delta table entry */
 	char type;
@@ -81,9 +80,23 @@ static struct delent {		/* structure for delta table entry */
 	char *pred;
 } del;
 
-static void	getdel(), s_init(), set_keep(), add_q(), rem_q();
-static void	process(), validate(), read_to(), report();
-static int	getstats(), do_delt(), read_mod(), invalid(), chk_ix();
+	int	main __PR((int argc, char **argv));
+static void	process __PR((char *p_line, int argc, char **argv));
+static void	validate __PR((char *c_path, char *c_sid, char *c_type, char *c_name));
+static void	getdel __PR((struct delent *delp, char *lp));
+static void	read_to __PR((int ch, struct packet *pkt));
+static void	report __PR((int code, char *inp_line, char *file));
+static int	invalid __PR((char *i_sid));
+static char *	get_line __PR((struct packet *pkt));	/* function returning ptr to line read */
+static void	s_init __PR((struct packet *pkt, char *file));
+static int	read_mod __PR((struct packet *pkt));
+static void	add_q __PR((struct packet *pkt, int ser, int keep, int iord, int user));
+static void	rem_q __PR((struct packet *pkt, int ser));
+static void	set_keep __PR((struct packet *pkt));
+static int	chk_ix __PR((struct queue *new, struct queue *head));
+static int	do_delt __PR((struct packet *pkt, int goods, char *d_sid));
+static int	getstats __PR((struct packet *pkt));
+
 
 /* This is the main program that determines whether the command line
  * comes from the standard input or read off the original command
@@ -107,12 +120,10 @@ char	*argv[];
 	/* 
 	 * Set directory to search for general l10n SCCS messages.
 	 */
-#ifdef	USE_NLS
 	bindtextdomain(NOGETTEXT("SUNW_SPRO_SCCS"),
 	   NOGETTEXT("/usr/ccs/lib/locale/"));
 	
 	textdomain(NOGETTEXT("SUNW_SPRO_SCCS"));
-#endif
 
 	/*
 	Set flags for 'fatal' to issue message, call clean-up
@@ -343,7 +354,6 @@ char	*c_sid;
 char	*c_type;
 char	*c_name;
 {
-	char *auxf();
 	register char	*l;
 	int	goods,goodt,goodn,hadmflag;
 
@@ -597,7 +607,7 @@ register struct packet *pkt;
 {
 	char	buf[DEF_LINE_SIZE];
 	int	eof;
-	register size_t read = 0;
+	register size_t nread = 0;
 	register size_t used = 0;
 	register signed char *p;
 	register unsigned char *u_p;
@@ -605,9 +615,9 @@ register struct packet *pkt;
 	/* read until EOF or newline encountered */
 	do {
 		if (!(eof = (fgets(buf, sizeof(buf), pkt->p_iop) == NULL))) {
-			read = strlen(buf);
+			nread = strlen(buf);
 
-			if ((used + read) >=  pkt->p_line_size) {
+			if ((used + nread) >=  pkt->p_line_size) {
 				pkt->p_line_size += sizeof(buf);
 				pkt->p_line = (char*) realloc(pkt->p_line, pkt->p_line_size);
 				if (pkt->p_line == NULL) {
@@ -616,7 +626,7 @@ register struct packet *pkt;
 			}
 
 			strcpy(pkt->p_line + used, buf);
-			used += read;
+			used += nread;
 		}
 	} while (!eof && (pkt->p_line[used-1] != '\n'));
 
