@@ -30,9 +30,11 @@
 
 #ident	"@(#)error.c"
 #ident	"@(#)sccs:lib/cassi/error.c"
-#include <stdio.h>
+
+#include <defines.h>
+
 void error(dummy)	
-	char *dummy;
+	const char *dummy;
 	{
 	 printf("%s\n",dummy);
 	}
