@@ -74,7 +74,11 @@ extern FILE		*trace;
 USXALLOC();
 # endif
 
-static int	copyrest();
+static int ftrans	__PR((int opcode, char *file1, char *file2, char *area, int asize));
+static int copyrest	__PR((FILE *fp1, FILE *fp2, char *place, int bsize));
+static int getrec	__PR((FILE *file, char *buffer, int recsep, int rectype, int maxlen));
+static int rec_cmp	__PR((char **args, char **fmatch, int recsep));
+static int argchop	__PR((char *s, int fldsep, char **sargs));
 
 /*
  *	ftrans -- Handle routine file transfer operations.
@@ -199,7 +203,7 @@ int	rectype,				/* FIXED or VARYING length. */
 		count = 0;
 		while ((lc = fgetc (file)) != EOF) {
 			if ((char) lc == recsep) {
-				buffer[count] = NULL;
+				buffer[count] = '\0';
 				TR("Getrec: returns buffer=(%s)\n", buffer, EMPTY, EMPTY);
 				return (DONE);
 				}
@@ -210,7 +214,7 @@ int	rectype,				/* FIXED or VARYING length. */
 				}
 			}
 		TR("Getrec: end of file\n", EMPTY, EMPTY, EMPTY);
-		buffer[count] = NULL;
+		buffer[count] = '\0';
 		return (FILE1EOF);
 		}
 	else
@@ -256,13 +260,13 @@ char	*s,				/* The string to seperate. */
 
 	while (s[i] == fldsep || (fldsep == WHITE && (s[i] == ' '
 	  || s[i] == '\t')))
-		s[i++] = NULL;					/* Skip initial blank fields. */
+		s[i++] = '\0';					/* Skip initial blank fields. */
 
-	while (s[i] != NULL) {
+	while (s[i] != '\0') {
 		if (s[i] == fldsep || (fldsep == WHITE && (s[i] == ' '
 		  || s[i] == '\t')))
-			s[i] = NULL;				/* Insert a string terminater. */
-		else if ((i > 0 && s[i - 1] == NULL) || i == 0)
+			s[i] = '\0';				/* Insert a string terminater. */
+		else if ((i > 0 && s[i - 1] == '\0') || i == 0)
 			sargs[subs++] = &s[i];		/* An argument begins here. */
 		i++;
 		}
@@ -291,12 +295,12 @@ int		maxlen;							/* Maximum length of record. */
 char	*fmatch[],						/* Fields to match. */
 		*usrbuf,						/* User's copy of matching record. */
 		*usrmatch[];					/* Pointers to arguments. */
-int		(*chop)(),						/* Routine to seperate the fields. */
-		(*comparef)();					/* Routine to compare records. */
+int		(*chop) __PR((char *, int, char **)),		/* Routine to seperate the fields. */
+		(*comparef) __PR((char **, char **, int));	/* Routine to compare records. */
 {
-	char	**arg,						/* Pointers to the fields. */
-			*realrec,					/* A copy of what was actually read. */
-			*hackrec;					/* A place to keep the fields. */
+	char	**arg = NULL,					/* Pointers to the fields. */
+		*realrec = NULL,				/* A copy of what was actually read. */
+		*hackrec = NULL;				/* A place to keep the fields. */
 
 	int		cmpstat,					/* Comparison status. */
 			retcode,					/* Return code. */
@@ -304,7 +308,7 @@ int		(*chop)(),						/* Routine to seperate the fields. */
 			rectype,					/* FIXED or VARIED record size. */
 			i, j;						/* Looping variable. */
 
-	FILE	*fp1, *fp2;					/* Pointers to file1 and file2. */
+	FILE	*fp1, *fp2 = NULL;				/* Pointers to file1 and file2. */
 
 	TR("Sweep: opcode=%d file1=(%s) file2=(%s)\n", opcode, file1, file2);
 	TR(".. recsep=(%c) fldsep=(%c) maxlen=%d ", recsep, fldsep, maxlen);
@@ -475,7 +479,7 @@ begin:
 			}
 		}
 
-	if (recsep == NULL)
+	if (recsep == 0)
 		rectype = FIXED;
 	else
 		rectype = VARIED;
@@ -486,7 +490,7 @@ begin:
 		strncpy (hackrec, realrec, (unsigned) maxlen);
 
 		/* Seperate the command into arguments. */
-		if (chop == (int (*)()) NULL)
+		if (chop == (int (*) __PR((char *, int, char **))) NULL)
 			i = argchop (hackrec, fldsep, arg);
 		else
 			i = (*chop) (hackrec, fldsep, arg);
@@ -494,7 +498,7 @@ begin:
 			break;						/* Something funny in record. */
 
 		/* Now, determine the alphabetic status of this record. */
-		if (comparef == (int (*)()) NULL)
+		if (comparef == (int (*) __PR((char **, char **, int))) NULL)
 			cmpstat = rec_cmp (arg, fmatch, recsep);
 		else
 			cmpstat = (*comparef) (arg, fmatch, recsep);
