@@ -39,8 +39,8 @@ register char ch;
 int put;
 {
 	register char *p;
-	void	fmterr(), putline();
-	char 	*getline();
+/*	void	fmterr(), putline();*/
+/*	char 	*getline();*/
 
 	while ((p = getline(pkt)) != NULL && !(*p++ == CTLCHAR && *p == ch))
 		pkt->p_wrttn = (char) put;
