@@ -38,7 +38,7 @@
 */
 
 # include	<stdio.h>
-# include	<sys/types.h>
+# include	<defines.h>
 # include	<macros.h>
 
 FILE *
