@@ -32,6 +32,7 @@
 #ident	"@(#)sccs:lib/mpwlib/xunlink.c"
 
 #include <schily/mconfig.h>
+#include <defines.h>
 #include <i18n.h>
 
 /*
@@ -44,7 +45,6 @@ int
 xunlink(f)
 const char	*f;
 {
-	int	unlink(), xmsg();
 	if (unlink(f))
 		return(xmsg(f, NOGETTEXT("xunlink")));
 	return(0);
